# camgeos


[![image](https://img.shields.io/pypi/v/camgeos.svg)](https://pypi.python.org/pypi/camgeos)
[![image](https://img.shields.io/conda/vn/conda-forge/camgeos.svg)](https://anaconda.org/conda-forge/camgeos)


**This is my demo python package.**


-   Free software: MIT license
-   Documentation: https://chungsarit.github.io/camgeos
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) project template.
